@@ -2,8 +2,8 @@ from challonge_wrapper.challonge_helpers import (
     set_api_key
 )
 
-from challonge_wrapper.challonge_tourney import (
-    init_tourney
+from challonge_wrapper.challonge_tournament import (
+    init_tournament
 )
 
 from challonge_wrapper.challonge_participant import (
